One of a set of functions that can be passed to argument r in the
calculate_dQALY function, that implement common discounting regimes.
Passing r_lt_health to calculate_dQALY means choosing to
apply the Green Book recommended declining long term discount rate for health
or life values when calculating QALY loss due to death.