One of a set of functions that can be passed to argument r in the
calculate_dQALY function, that implement common discounting regimes.
Passing r_lt_health_reduced to calculate_dQALY means choosing to
apply the Green Book recommended rate reduced by excluding pure social time
preference (relevant if intervention may effect substantial/irreversible
wealth transfers between generations) when calculating QALY loss due to death.